package
module
Version:
v0.3.1
Opens a new window with list of versions in this module.
Published: Mar 15, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package workflowpluginwebsocket provides the WebSocket workflow plugin.
NewWebSocketPlugin returns the WebSocket SDK plugin provider.
type Hub interface {
BroadcastToRoom(room string, msg []byte) int
}
Hub is an exported interface for the WebSocket hub's broadcast capabilities.
Satisfied by the internal hub after the ws.server module is initialized.
GetHub returns the global WebSocket hub once the ws.server module has been
initialized. Returns nil if the module has not started yet.
Source Files
¶
Directories
¶
cmd
|
|
|
|
|
|
|
|
Click to show internal directories.
Click to hide internal directories.